The server responded with a strange HTTP status code. This is a non-issue
however exotic HTTP response status codes can provide useful insights
into the behavior of the web application and assist with the information
security analysis.